@@ -1,28 +1,17 @@
 package Email::Valid;
-require 5.006;
+
 use strict;
-use warnings;
 use vars qw( $VERSION $RFC822PAT %AUTOLOAD $AUTOLOAD $NSLOOKUP_PAT
              @NSLOOKUP_PATHS $Details $Resolver $Nslookup_Path 
              $DNS_Method $TLD $Debug );
-
 use Carp;
 use IO::File;
 use Mail::Address;
 use File::Spec;
 
-use bytes;
-
-$VERSION = '0.183_001';
-
-%AUTOLOAD = (
-  fqdn     => 1,
-  fudge    => 1,
-  mxcheck  => 1,
-  tldcheck => 1,
-  local_rules => 1,
-);
+$VERSION = '0.16';
 
+%AUTOLOAD = ( mxcheck => 1, tldcheck => 1, fudge => 1, fqdn => 1, local_rules => 1 );
 $NSLOOKUP_PAT = 'preference|serial|expire|mail\s+exchanger';
 @NSLOOKUP_PATHS = File::Spec->path();
 
@@ -35,7 +24,7 @@ sub new {
   $class = ref $class || $class;
   bless my $self = {}, $class;
   $self->_initialize;
-  %$self = $self->_rearrange([ keys %AUTOLOAD ], \@_);
+  %$self = $self->_rearrange([qw( mxcheck tldcheck fudge fqdn local_rules )], \@_);
   return $self;
 }
 
@@ -48,7 +37,7 @@ sub _initialize {
   $self->{fqdn}        = 1;
   $self->{local_rules} = 0;
   $self->{details}     = $Details = undef;
-}
+}            
 
 # Pupose: handles named parameter calling style
 sub _rearrange {
@@ -59,8 +48,8 @@ sub _rearrange {
 
   ref $self ? %args = %$self : _initialize( \%args );
   return %args unless @params;
-
-  unless ($params[0] =~ /^-/ and @params > 1) {
+  
+  unless ($params[0] =~ /^-/) {
     while(@params) {
       croak 'unexpected number of parameters' unless @names;
       $args{ lc shift @names } = shift @params;
@@ -92,7 +81,7 @@ sub rfc822 {
   my %args = $self->_rearrange([qw( address )], \@_);
 
   my $addr = $args{address} or return $self->details('rfc822');
-  $addr = $addr->address if eval { $addr->isa('Mail::Address') };
+  $addr = $addr->address if UNIVERSAL::isa($addr, 'Mail::Address');
 
   return $self->details('rfc822') unless $addr =~ m/^$RFC822PAT$/o;
 
@@ -102,11 +91,11 @@ sub rfc822 {
 # Purpose: attempt to locate the nslookup utility 
 sub _find_nslookup {
   my $self = shift;
-
+ 
   my $ns = 'nslookup';
+  $ns .= '.exe' if $^O =~ /win32/i;
   foreach my $path (@NSLOOKUP_PATHS) {
     my $file = File::Spec->catfile($path, $ns);
-    return "$file.exe" if ($^O eq 'MSWin32') and -x "$file.exe" and !-d _;
     return $file if -x $file and !-d _;
   }
   return undef;
@@ -117,7 +106,7 @@ sub _select_dns_method {
   # if Net::DNS is available
   eval { require Net::DNS };
   return $DNS_Method = 'Net::DNS' unless $@;
-
+ 
   $DNS_Method = 'nslookup';
 }
 
@@ -130,10 +119,10 @@ sub _net_dns_query {
 
   my $packet = $Resolver->send($host, 'A') or croak $Resolver->errorstring;
   return 1 if $packet->header->ancount;
-
+ 
   $packet = $Resolver->send($host, 'MX') or croak $Resolver->errorstring;
   return 1 if $packet->header->ancount;
-
+ 
   return $self->details('mx');               
 }
 
@@ -152,34 +141,21 @@ sub _nslookup_query {
   return 1 if gethostbyname $host;
 
   # Check for an MX record
-  if ($^O eq 'MSWin32' or $^O eq 'Cygwin') {
-    # Oh no, we're on Windows!
-    require IO::CaptureOutput;
-    my $response = IO::CaptureOutput::capture_exec(
-     $Nslookup_Path, '-query=mx', $host
-    );
-    croak "unable to execute nslookup '$Nslookup_Path': exit $?" if $?;
+  if (my $fh = new IO::File '-|') {
+    my $response = <$fh>;
     print STDERR $response if $Debug;
+    close $fh;
     $response =~ /$NSLOOKUP_PAT/io or return $self->details('mx');
     return 1;
   } else {
-    # phew, we're not on Windows!
-    if (my $fh = IO::File->new('-|')) {
-      my $response = <$fh>;
-      print STDERR $response if $Debug;
-      close $fh;
-      $response =~ /$NSLOOKUP_PAT/io or return $self->details('mx');
-      return 1;
-    } else {
-      open OLDERR, '>&STDERR' or croak "cannot dup stderr: $!";
-      open STDERR, '>&STDOUT' or croak "cannot redirect stderr to stdout: $!";
-      {
-        exec $Nslookup_Path, '-query=mx', $host;
-      }
-      open STDERR, ">&OLDERR";
-      croak "unable to execute nslookup '$Nslookup_Path': $!";
-    }                                                                             
-  }
+    open OLDERR, '>&STDERR' or croak "cannot dup stderr: $!";
+    open STDERR, '>&STDOUT' or croak "cannot redirect stderr to stdout: $!";
+    {
+      exec $Nslookup_Path, '-query=mx', $host;
+    }
+    open STDERR, ">&OLDERR";
+    croak "unable to execute nslookup '$Nslookup_Path': $!";
+  }                                                                             
 }
 
 # Purpose: Check whether a top level domain is valid for a domain.
@@ -187,7 +163,7 @@ sub tld {
   my $self = shift;
   my %args = $self->_rearrange([qw( address )], \@_);
 
-  unless (eval {require Net::Domain::TLD; Net::Domain::TLD->VERSION(1.65); 1}) {
+  unless (eval { require Net::Domain::TLD; 1 }) {
     die "Net::Domain::TLD not available";
   }
 
@@ -223,11 +199,11 @@ sub _host {
   my $self = shift;
   my $addr = shift;
 
-  $addr = $addr->address if eval { $addr->isa('Mail::Address') };
+  $addr = $addr->address if UNIVERSAL::isa($addr, 'Mail::Address');
 
   my $host = ($addr =~ /^.*@(.*)$/ ? $1 : $addr);
   $host =~ s/\s+//g;
-
+ 
   # REMOVE BRACKETS IF IT'S A DOMAIN-LITERAL
   #   RFC822 3.4.6
   #   Square brackets ("[" and "]") are used to indicate the
@@ -268,31 +244,6 @@ sub _local_rules {
   1;  
 }
 
-sub _valid_domain_parts {
-  my ($self, $string) = @_;
-
-  return unless $string and length $string <= 255;
-  return if $string =~ /\.\./;
-  my @labels = split /\./, $string;
-
-  for my $label (@labels) {
-    return 0 unless $self->_is_domain_label($label);
-  }
-  return scalar @labels;
-}
-
-sub _is_domain_label {
-  my ($self, $string) = @_;
-  return unless $string =~ /\A
-    [A-Z0-9]          # must start with an alnum
-    (?:
-      [-A-Z0-9]*      # then maybe a dash or alnum
-      [A-Z0-9]        # finally ending with an alnum
-    )?                # lather, rinse, repeat
-  \z/ix;
-  return 1;
-}
-
 # Purpose: Put an address through a series of checks to determine 
 #          whether it should be considered valid.
 sub address {
@@ -301,13 +252,12 @@ sub address {
                                     local_rules )], \@_);
 
   my $addr = $args{address} or return $self->details('rfc822');
-  $addr = $addr->address if eval { $addr->isa('Mail::Address') };
+  $addr = $addr->address if UNIVERSAL::isa($addr, 'Mail::Address');
 
   $addr = $self->_fudge( $addr ) if $args{fudge};
-  $self->rfc822( -address => $addr ) or return undef;
+  $self->rfc822( $addr ) or return undef;
 
   ($addr) = Mail::Address->parse( $addr );
-
   $addr or return $self->details('rfc822'); # This should never happen
 
   if ($args{local_rules}) {
@@ -316,18 +266,15 @@ sub address {
   }
 
   if ($args{fqdn}) {
-    $self->_valid_domain_parts($addr->host) > 1
-      or return $self->details('fqdn');
+    $addr->host =~ /^.+\..+$/ or return $self->details('fqdn');
   }
 
   if ($args{mxcheck}) {
-    # I'm not sure this ->details call is needed, but I'll test for it later.
-    # The whole ->details thing is... weird. -- rjbs, 2006-06-08
-    $self->mx( $addr->host ) or return $self->details('mxcheck');
+    $self->mx( $addr->host ) or return;
   }
 
   if ($args{tldcheck}) {
-    $self->tld( $addr->host ) or return $self->details('tldcheck');
+    $self->tld( $addr->host ) or return;
   }
 
   return (wantarray ? ($addr->address, $addr) : $addr->address);  
@@ -514,11 +461,6 @@ the behavior of the resolver (e.g. change the default tcp_timeout
 value) by manipulating the global Net::DNS::Resolver instance stored in
 $Email::Valid::Resolver.     
 
-=item tld ( <ADDRESS> )
-
-This method determines whether the domain part of an address is in a recognized
-top-level domain.
-
 =item rfc822 ( <ADDRESS> )
 
 This method determines whether an address conforms to the RFC822
